    	vibes:

    		agenda:
    			[ ] can propose a new friendship popularity vibe
    				with a { stamp } from your proposal vibe.

    					reasons:
    						your proposal vibe was compromised.

    		vernacular:
    			friend vibes
    				friend popularity vibe

    				friend essence vibe
    				friend essence intro

    			proposal vibes
    				proposal popularity vibe,

    				proposal essence vibe
    				proposal essence intro

    			popularity
    				description: the public key

    		legend:

    			---------------------------------

    			vibe -> key

    				similar:
    					certificate:
    					license:

    			friendship vibe -> voter

    				similar:
    					relationship
    					friendship
    					union
    					consensus:
    					decorum:
    					geniality:
    					support:
    					ratification:
    					participant:
    					voter:
    					ruler:
    					leader:

    			proposal vibe -> sending money, etc.

    				similar:
    					petition: